==> haskell-th-utilities-0.2.5.2-96.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-th-utilities.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-utilities
version:              0.2.5.2
visibility:           public
id:                   th-utilities-0.2.5.2-J2DMKJPSd4LGWTVFZxI2Jz
key:                  th-utilities-0.2.5.2-J2DMKJPSd4LGWTVFZxI2Jz
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/fpco/th-utilities#readme
synopsis:
    Collection of useful functions for use with Template Haskell

category:             Template Haskell
abi:                  711f9852d480d9ff7b6abfe952a000e1
exposed:              True
exposed-modules:
    TH.Derive TH.Derive.Storable TH.FixQ TH.ReifySimple
    TH.RelativePaths TH.Utilities

hidden-modules:       TH.Derive.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/th-utilities-0.2.5.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/th-utilities-0.2.5.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/th-utilities-0.2.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-utilities
hs-libraries:         HSth-utilities-0.2.5.2-J2DMKJPSd4LGWTVFZxI2Jz
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.8.5 filepath-1.4.300.1
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ
    syb-0.7.3-7GPFF4ffw0kLXaCjDkD2wt template-haskell-2.20.0.0
    text-2.0.2 th-abstraction-0.5.0.0-HAFjiAO2nGN58SdxVZCnLH
    th-orphans-0.13.16-x2p4Pj1aYA6bkrdDunvhC

haddock-interfaces:
    /usr/share/doc/haskell-th-utilities/html/th-utilities.haddock

haddock-html:         /usr/share/doc/haskell-th-utilities/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-utilities-0.2.5.2-97-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-th-utilities.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-utilities
version:              0.2.5.2
visibility:           public
id:                   th-utilities-0.2.5.2-JmmA4lllUnMCOSfPDuSo5D
key:                  th-utilities-0.2.5.2-JmmA4lllUnMCOSfPDuSo5D
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/fpco/th-utilities#readme
synopsis:
    Collection of useful functions for use with Template Haskell

category:             Template Haskell
abi:                  3e1393009be26b29725616c9eed9dd43
exposed:              True
exposed-modules:
    TH.Derive TH.Derive.Storable TH.FixQ TH.ReifySimple
    TH.RelativePaths TH.Utilities

hidden-modules:       TH.Derive.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/th-utilities-0.2.5.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/th-utilities-0.2.5.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/th-utilities-0.2.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-utilities
hs-libraries:         HSth-utilities-0.2.5.2-JmmA4lllUnMCOSfPDuSo5D
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.8.5 filepath-1.4.300.1
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi
    syb-0.7.3-MvqtDDcT2PHyhdKWhEKAp template-haskell-2.20.0.0
    text-2.0.2 th-abstraction-0.5.0.0-HAFjiAO2nGN58SdxVZCnLH
    th-orphans-0.13.16-7vRRXCTUh27LcIJ3KgMdVn

haddock-interfaces:
    /usr/share/doc/haskell-th-utilities/html/th-utilities.haddock

haddock-html:         /usr/share/doc/haskell-th-utilities/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
